import moment from 'moment'
import { fetch, apis } from '@/utils/request'

export default (id) => {
  if (!id) {
    return Promise.reject('没有找到有效的项目ID');
  }

  return new Promise((resolve, reject) => {
    fetch(apis.building.buildingGetById)({ urlData: { id } }).then((res) => {
      const data = { ...res }

      // 交房时间
      if (res.receivedDate) {
        data.receivedDate = moment(res.receivedDate)
      }

      // 标签
      if (res.buildingTag) {
        data.tag = res.buildingTag.map((x) => x.tagName)
      }

      // 主图 - 多个
      if (res.buildingImg) {
        data.avatarImage = res.buildingImg.map((x) => x.url)
      }

      // 封面 - 一个
      if (res.buildingListImg) {
        data.listImage = res.buildingListImg.map(item => item.url)[0]
      }

      // 视频
      if (res.videoUrl) {
        data.videoUrl = [].concat(res.videoUrl)
      }

      // 视频封面
      if (res.videoImage) {
        data.videoImage = res.videoImage[0].url
      }

      // POI 相关
      if (res.mapJson) {
        data.mapJson = JSON.parse(res.mapJson) || []
      }

      resolve(data)
    }).catch((err) => {
      reject(err.message || err)
    })
  })
}
