import React, { useEffect, useRef, useState } from 'react'
import { Typography, Tag, Input, Icon } from 'antd'
import MapPois from './MapPois'
import { arrRemove, arrAdd } from './utils'

/**
 * 因为周边TAG, 包含了2个部分的维护，一个是自定义周边，一个是地图周边，所以，需要单独写2个标签的处理
 */

export default React.forwardRef((props, ref) => {
  const inputRef = useRef()
  const poiRef = useRef()
  const [inputValue, setInputValue] = useState()
  const [inputVisible, setInputVisible] = useState(false)
  const [tags, setTags] = useState([])
  const [mapTags, setMapTags] = useState([])

  const handlePoiChange = (e) => {
    setMapTags(e)

    // 先清理原来的
    const tagArr = arrRemove(tags, mapTags)
    // 再加入新的
    const nwTags = arrAdd(tagArr, e)

    if (nwTags !== tags) {
      setTags(nwTags)
  
      if (props.onChange) {
        props.onChange(nwTags.join(','))
      }
    }
  }

  const handleClose = (tag) => {
    if (mapTags.indexOf(tag) > -1) {
      setMapTags(mapTags.filter((it) => it !== tag))
    }

    if (props.onChange) {
      props.onChange(tags.filter((t) => t !== tag).join(','))
    }
  }

  const handleInputConfirm = () => {
    const exists = tags.indexOf(inputValue) > -1
    if (!exists) {
      props.onChange(tags.concat(inputValue).join(','))
    }
    setInputVisible(false)
    setInputValue()
  }

  useEffect(() => {
    const arr = props.value ? props.value.split(',') : []
    setTags(arr)
  }, [props.value])

  return (
    <div>
      <MapPois ref={poiRef} pois={props.pois} onChange={handlePoiChange} />
      {
        tags.map((tag) => (
          <Tag key={tag} closable onClose={() => handleClose(tag)}>
            <Typography.Text>{tag}</Typography.Text>
          </Tag>
        ))
      }
      {
        inputVisible ? (
          <Input
            ref={inputRef}
            type="text"
            size="small"
            style={{ width: 80, display: inputVisible ? 'inline-block' : 'none' }}
            value={inputValue}
            onChange={e => setInputValue(e.target.value)}
            onBlur={handleInputConfirm}
            onPressEnter={handleInputConfirm}
          />
        ) : (
          <Tag onClick={() => setInputVisible(true)} style={{ background: '#fff', borderStyle: 'dashed' }}>
            <Icon type="plus" /> 新建
          </Tag>
        )
      }
    </div>
  )
})
